@@ -572,7 +572,9 @@ path_is_dir (const char *path)
 	is_dir = FALSE;
 	if (result == GNOME_VFS_OK)
 		is_dir = (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY);
-	
+	else
+		g_warning ("%s: %s\n", path, gnome_vfs_result_to_string (result));
+
 	g_free (escaped);
 	gnome_vfs_file_info_unref (info);
 
@@ -1400,10 +1402,13 @@ GnomeVFSURI *
 new_uri_from_path (const char *path)
 {
 	char        *escaped;
+	char        *uri_txt;
 	GnomeVFSURI *uri;
 
 	escaped = gnome_vfs_escape_path_string (path);
-	uri = gnome_vfs_uri_new (escaped);
+	uri_txt = g_strconcat ("file://", escaped, NULL);
+	uri = gnome_vfs_uri_new (uri_txt);
+	g_free (uri_txt);
 	g_free (escaped);
 
 	g_return_val_if_fail (uri != NULL, NULL);
@@ -1444,7 +1449,7 @@ resolve_all_symlinks (const char  *text_uri,
 	my_text_uri = g_strdup (text_uri);
 	info = gnome_vfs_file_info_new ();
 
-	for (p = my_text_uri; *p != 0;) {
+	for (p = my_text_uri; (p != NULL) && (*p != 0); ) {
 		char           *new_text_uri;
 		GnomeVFSURI    *new_uri;
 
@@ -1461,14 +1466,15 @@ resolve_all_symlinks (const char  *text_uri,
 		res = gnome_vfs_get_file_info_uri (new_uri, info, GNOME_VFS_FILE_INFO_DEFAULT);
 
 		if (res != GNOME_VFS_OK) {
-			gnome_vfs_uri_unref (new_uri);
-			goto out;
-		}
+			char *old_uri = my_text_uri;
+			my_text_uri = g_build_filename (old_uri, p, NULL);
+			g_free (old_uri);
+			p = NULL;
 
-		if (info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK &&
-		    info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SYMLINK_NAME) {
+		} else if (info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK &&
+			   info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SYMLINK_NAME) {
 			GnomeVFSURI *resolved_uri;
-			char        *resolved_text_uri = NULL;
+			char        *tmp_resolved_text_uri = NULL;
 
 			n_followed_symlinks++;
 			if (n_followed_symlinks > MAX_SYMLINKS_FOLLOWED) {
@@ -1478,17 +1484,17 @@ resolve_all_symlinks (const char  *text_uri,
 			}
 
 			resolved_uri = gnome_vfs_uri_resolve_relative (new_uri, info->symlink_name);
-			resolved_text_uri = new_path_from_uri (resolved_uri);
+			tmp_resolved_text_uri = new_path_from_uri (resolved_uri);
 			gnome_vfs_uri_unref (resolved_uri);
 
 			if (*p != 0) {
 				char *old_uri = my_text_uri;
-				my_text_uri = g_build_filename (resolved_text_uri, p, NULL);
+				my_text_uri = g_build_filename (tmp_resolved_text_uri, p, NULL);
 				g_free (old_uri);
-				g_free (resolved_text_uri);
+				g_free (tmp_resolved_text_uri);
 			} else {
 				g_free (my_text_uri);
-				my_text_uri = resolved_text_uri;
+				my_text_uri = tmp_resolved_text_uri;
 			}
 
 			p = my_text_uri;
@@ -1521,3 +1527,25 @@ get_dest_free_space (const char  *path)
 	else
 		return ret_val;
 }
+
+
+gboolean
+is_mime_type_writable (const char *mime_type)
+{
+	GSList *list, *scan;
+
+	list = gdk_pixbuf_get_formats();
+	for (scan = list; scan; scan = scan->next) {
+		GdkPixbufFormat *format = scan->data;
+		char **mime_types;
+		int i;
+		mime_types = gdk_pixbuf_format_get_mime_types (format);
+		for (i = 0; mime_types[i] != NULL; i++) 
+			if (strcmp (mime_type, mime_types[i]) == 0)
+				return gdk_pixbuf_format_is_writable (format);
+		g_strfreev (mime_types);
+	}
+	g_slist_free (list);
+	
+	return FALSE;
+}
