@@ -204,7 +204,7 @@ get_file_info (GThumbWindow *window)
 	char       *file_size_txt;
 	int         zoom;
 	char       *file_info;
-	char        time_txt[50];
+	char        time_txt[50], *utf8_time_txt;
 	time_t      timer;
 	struct tm  *tm;
 
@@ -221,15 +221,18 @@ get_file_info (GThumbWindow *window)
 	timer = get_file_mtime (window->image_path);
 	tm = localtime (&timer);
 	strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
+	utf8_time_txt = g_locale_to_utf8 (time_txt, -1, 0, 0, 0);
 
-	file_info = g_strdup_printf ("%d/%d - <tt>%s</tt>\n<i>%s (%d%%) - %s - %s </i>",
-				     gth_file_list_pos_from_path (window->file_list, window->image_path) + 1,
-				     gth_file_list_get_length (window->file_list),
-				     e_filename,
+	file_info = g_strdup_printf ("<small><i>%s (%d%%) - %s - %s </i>\n%d/%d - <tt>%s</tt></small>",
 				     size_txt,
 				     zoom,
 				     file_size_txt,
-				     time_txt);
+				     utf8_time_txt,
+				     gth_file_list_pos_from_path (window->file_list, window->image_path) + 1,
+				     gth_file_list_get_length (window->file_list),
+				     e_filename);
+
+	g_free (utf8_time_txt);
 	g_free (e_filename);
 	g_free (size_txt);
 	g_free (file_size_txt);
@@ -294,7 +297,7 @@ show_comment_on_image (GThumbWindow *window,
 		marked_text = g_strdup (file_info); /*g_strdup_printf ("<i>%s</i>", file_info);*/
 	else {
 		e_comment = g_markup_escape_text (comment, -1);
-		marked_text = g_strdup_printf ("<b>%s</b>\n%s", 
+		marked_text = g_strdup_printf ("<b>%s</b>\n\n%s", 
 					       e_comment, 
 					       file_info);
 		g_free (e_comment);
@@ -575,11 +578,11 @@ image_key_press_cb (GtkWidget   *widget,
 	case GDK_r:
 	case GDK_R:
 	case GDK_bracketright:
-		alter_image_rotate_command_impl (NULL, window, NULL);
+		alter_image_rotate_90_command_impl (NULL, window, NULL);
 		break;
 
 	case GDK_bracketleft:
-		alter_image_rotate_cc_command_impl (NULL, window, NULL);
+		alter_image_rotate_90_cc_command_impl (NULL, window, NULL);
 		break;
 
 		/* Mirror. */
@@ -960,6 +963,8 @@ fullscreen_start (FullScreen   *fullscreen,
 	window->fullscreen = TRUE;
 	fullscreen->related_win = window;
 	fullscreen->viewer = window->viewer;
+	fullscreen->msg_save_modified_image = eel_gconf_get_boolean (PREF_MSG_SAVE_MODIFIED_IMAGE, TRUE);
+	eel_gconf_set_boolean (PREF_MSG_SAVE_MODIFIED_IMAGE, FALSE);
 
 	wmspec_change_state (TRUE,
 			     fullscreen->window->window,
@@ -972,6 +977,8 @@ fullscreen_start (FullScreen   *fullscreen,
 	if (! eel_gconf_get_boolean (PREF_BLACK_BACKGROUND, FALSE))
 		image_viewer_set_black_background (IMAGE_VIEWER (fullscreen->viewer), TRUE);
 
+	gtk_widget_set_sensitive (fullscreen->related_win->app, FALSE);
+
 	/* capture keyboard events. */
 
 	if (! fullscreen->wm_state_fullscreen_support) {
@@ -1055,6 +1062,8 @@ fullscreen_stop (FullScreen *fullscreen)
 	fullscreen->related_win = NULL;
 	comment_visible = FALSE;
 
+	eel_gconf_set_boolean (PREF_MSG_SAVE_MODIFIED_IMAGE, fullscreen->msg_save_modified_image);
+
 	/* release keyboard focus. */ 
 
 	if (! fullscreen->wm_state_fullscreen_support) {
@@ -1071,6 +1080,7 @@ fullscreen_stop (FullScreen *fullscreen)
 	gtk_widget_realize (window->viewer);
 	fullscreen->viewer = NULL;
 
+	gtk_widget_set_sensitive (window->app, TRUE);
 	gtk_widget_show_all (window->app);
 
 	/* restore widgets visiblity */
